@@ -6,11 +6,11 @@ from cow.plugins.sqlalchemy_plugin import SQLAlchemyPlugin
 from cow.plugins.redis_plugin import RedisPlugin
 from tornado.httpclient import AsyncHTTPClient
 import tornado.locale
-#from toredis import Client
 import redis
 from materialgirl import Materializer
 from materialgirl.storage.redis import RedisStorage
 
+from holmes.handlers.auth import AuthenticateHandler
 from holmes.handlers.page import (
     PageHandler, PageReviewsHandler, PageViolationsPerDayHandler, NextJobHandler
 )
@@ -36,6 +36,8 @@ from holmes.handlers.limiter import LimiterHandler
 from holmes.handlers.domains_violations_prefs import (
     DomainsViolationsPrefsHandler
 )
+from holmes.handlers.users_violations_prefs import UsersViolationsPrefsHandler
+from holmes.handlers.users import UserLocaleHandler
 
 from holmes.handlers.bus import EventBusHandler
 from holmes.event_bus import EventBus
@@ -112,7 +114,10 @@ class HolmesApiServer(Server):
             ('/last-requests/?', LastRequestsHandler),
             ('/last-requests/status-code/?', LastRequestsStatusCodeHandler),
             ('/last-requests/failed-responses/?', FailedResponsesHandler),
-            ('/version/?', VersionHandler),
+            ('/version/?', VersionHandler, dict(is_public=True)),
+            ('/authenticate/?', AuthenticateHandler, dict(is_public=True)),
+            ('/users/violations-prefs/?', UsersViolationsPrefsHandler),
+            ('/users/locale/?', UserLocaleHandler),
         ]
 
         return tuple(handlers)
@@ -197,7 +202,10 @@ class HolmesApiServer(Server):
 
         self.redis_material = redis.StrictRedis(host=host, port=port, db=0)
 
-        self.application.girl = Materializer(storage=RedisStorage(redis=self.redis_material))
+        self.application.girl = Materializer(
+            storage=RedisStorage(redis=self.redis_material),
+            load_on_cachemiss=self.config.get('MATERIAL_GIRL_LOAD_ON_CACHEMISS', True)
+        )
 
         configure_materials(self.application.girl, self.application.db, self.config)
 
