@@ -16,7 +16,7 @@ from sqlalchemy.orm import scoped_session
 from holmes import __version__
 from holmes.reviewer import Reviewer
 from holmes.utils import load_classes, count_url_levels, get_domain_from_url
-from holmes.models import Page, Request, Key, DomainsViolationsPrefs
+from holmes.models import Request, Key, DomainsViolationsPrefs
 from holmes.cli import BaseCLI
 
 
@@ -241,7 +241,7 @@ class HolmesWorker(BaseWorker):
                 search_provider=self.search_provider,
                 async_get=self.async_get,
                 wait=self.otto.wait,
-                wait_timeout=0,  # max time to wait for all requests to finish
+                wait_timeout=120,  # max time to wait for all requests to finish
                 db=self.db,
                 cache=self.cache,
                 publish=self.publish,
